==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/core/server/saved_objects/import/regenerate_ids.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.regenerateIds = void 0;

var _uuid = require("uuid");

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Takes an array of saved objects and returns an importIdMap of randomly-generated new IDs.
 *
 * @param objects The saved objects to generate new IDs for.
 */
const regenerateIds = objects => {
  const importIdMap = objects.reduce((acc, object) => {
    return acc.set(`${object.type}:${object.id}`, {
      id: (0, _uuid.v4)(),
      omitOriginId: true
    });
  }, new Map());
  return importIdMap;
};

exports.regenerateIds = regenerateIds;

==> opensearch-dashboards-2.16.0.tgz: opensearch-dashboards/src/core/server/saved_objects/import/regenerate_ids.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.regenerateIds = void 0;
var _uuid = require("uuid");
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Takes an array of saved objects and returns an importIdMap of randomly-generated new IDs.
 *
 * @param objects The saved objects to generate new IDs for.
 */
const regenerateIds = (objects, dataSourceId) => {
  const importIdMap = objects.reduce((acc, object) => {
    return object.type === 'data-source' ? acc : acc.set(`${object.type}:${object.id}`, {
      id: dataSourceId ? `${dataSourceId}_${(0, _uuid.v4)()}` : (0, _uuid.v4)(),
      omitOriginId: true
    });
  }, new Map());
  return importIdMap;
};
exports.regenerateIds = regenerateIds;
